@@ -15,9 +15,11 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Sequence
 
+from botocore.response import StreamingBody
+
 from .literals import StatementStatusStringType, StatusStringType
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -242,7 +244,7 @@ ExecuteStatementOutputTypeDef = TypedDict(
 FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
-        "blobValue": bytes,
+        "blobValue": StreamingBody,
         "booleanValue": bool,
         "doubleValue": float,
         "isNull": bool,
